@@ -2,7 +2,7 @@
 #include <stdio.h>
 #include "wv.h"
 
-void wvGetBKF(BKF *item,FILE *fd)
+void wvGetBKF(BKF *item,wvStream *fd)
 	{
 	U16 temp16;
 #ifdef PURIFY
@@ -25,7 +25,7 @@ void wvInitBKF(BKF *item)
     item->fCol = 0;
 	}
 
-int wvGetBKF_PLCF(BKF **bkf,U32 **pos,U32 *nobkf,U32 offset,U32 len,FILE *fd)
+int wvGetBKF_PLCF(BKF **bkf,U32 **pos,U32 *nobkf,U32 offset,U32 len,wvStream *fd)
 	{
 	U32 i;
 	if (len == 0)
@@ -51,7 +51,7 @@ int wvGetBKF_PLCF(BKF **bkf,U32 **pos,U32 *nobkf,U32 offset,U32 len,FILE *fd)
 			free(pos);
             return(1);
             }
-        fseek(fd,offset,SEEK_SET);
+        wvStream_goto(fd,offset);
         for(i=0;i<=*nobkf;i++)
             (*pos)[i]=read_32ubit(fd);
         for(i=0;i<*nobkf;i++)
