@@ -34,14 +34,14 @@ void wvSetPixelsPerInch(S16 hpixels,S16 vpixels)
 float wvTwipsToHPixels(S16 twips)
 	{
 	float ret = ((float)(pperhi*twips))/TWIPS_PER_INCH;
-	wvError(("ret is %f\n",ret));
+	wvTrace(("ret is %f\n",ret));
 	return(ret);
 	}
 
 float wvTwipsToVPixels(S16 twips)
 	{
 	float ret = ((float)(ppervi*twips))/TWIPS_PER_INCH;
-	wvError(("ret is %f\n",ret));
+	wvTrace(("ret is %f\n",ret));
 	return(ret);
 	}
 
@@ -49,7 +49,7 @@ float wvTwipsToMM(S16 twips)
 	{
 	float ret;
 	ret = ((float)twips)/TWIPS_PER_INCH;
-	ret = ret*25.0;
+	ret = ret*(float)25.0;
 	return(ret);
 	}
 
